---
{% if infra_vm_use_cirros | default(true) %}
aio_interface: eth0
{% else %}
# Required for official cloud images (CentOS Stream 10, Rocky Linux 10, Ubuntu)
aio_interface: ens2
{% endif %}

# Route via the seed-hypervisor to the outside world.
aio_gateway: 192.168.33.4
